==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Layer/Layer.base.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import { MountingPortal } from 'portal-vue';
import { registerLayer, unregisterLayer, getDefaultTarget } from './Layer.notification.js';
import { getStyles } from './Layer.styles.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var LayerBase = function (_BaseComponent) {
  _inherits(LayerBase, _BaseComponent);

  var _super = _createSuper(LayerBase);

  function LayerBase() {
    var _this;

    _classCallCheck(this, LayerBase);

    _this = _super.apply(this, arguments);
    _this.hasTarget = false;
    return _this;
  }

  _createClass(LayerBase, [{
    key: "mounted",
    value: function mounted() {
      this.createElement();

      if (this.hostId) {
        registerLayer(this.hostId, this.createElement);
      }
    }
  }, {
    key: "beforeDestroy",
    value: function beforeDestroy() {
      var hostId = this.hostId;

      if (this.hostId) {
        unregisterLayer(this.hostId, this.createElement);
      }
    }
  }, {
    key: "createElement",
    value: function createElement() {
      var doc = this.$el.ownerDocument;
      var host = this.getHost();

      if (!doc || !host) {
        this.hasTarget = false;
        return;
      }

      this.hasTarget = true;
    }
  }, {
    key: "getHost",
    value: function getHost() {
      var doc = this.$el.ownerDocument;

      if (!doc) {
        return undefined;
      }

      if (this.hostId) {
        return doc.getElementById(this.hostId);
      } else {
        var defaultHostSelector = getDefaultTarget();
        return defaultHostSelector ? doc.querySelector(defaultHostSelector) : doc.body;
      }
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      if (!this.hasTarget) return;
      var classNames = this.classNames,
          hostId = this.hostId,
          append = this.append;
      return h(MountingPortal, {
        "attrs": {
          "mount-to": hostId ? "#".concat(hostId) : 'body',
          "append": append
        }
      }, [h("div", {
        "class": classNames.root
      }, [h("div", {
        "class": classNames.content
      }, [this.$slots["default"]])])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var className = this.className,
          theme = this.theme;
      return getClassNames(getStyles, {
        theme: theme,
        className: className,
        isNotHost: !this.hostId
      });
    }
  }]);

  return LayerBase;
}(BaseComponent);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], LayerBase.prototype, "hostId", void 0);

__decorate([Prop({
  type: Boolean,
  "default": true
}), __metadata("design:type", Boolean)], LayerBase.prototype, "append", void 0);

LayerBase = __decorate([Component], LayerBase);

export { LayerBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Layer/Layer.base.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import { MountingPortal } from 'portal-vue';
import { registerLayer, unregisterLayer, getDefaultTarget } from './Layer.notification.js';
import { getStyles } from './Layer.styles.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var LayerBase = function (_BaseComponent) {
  _inherits(LayerBase, _BaseComponent);

  var _super = _createSuper(LayerBase);

  function LayerBase() {
    var _this;

    _classCallCheck(this, LayerBase);

    _this = _super.apply(this, arguments);
    _this.hasTarget = false;
    return _this;
  }

  _createClass(LayerBase, [{
    key: "mounted",
    value: function mounted() {
      this.createElement();

      if (this.hostId) {
        registerLayer(this.hostId, this.createElement);
      }
    }
  }, {
    key: "beforeDestroy",
    value: function beforeDestroy() {
      var hostId = this.hostId;

      if (this.hostId) {
        unregisterLayer(this.hostId, this.createElement);
      }
    }
  }, {
    key: "createElement",
    value: function createElement() {
      var doc = this.$el.ownerDocument;
      var host = this.getHost();

      if (!doc || !host) {
        this.hasTarget = false;
        return;
      }

      this.hasTarget = true;
    }
  }, {
    key: "getHost",
    value: function getHost() {
      var doc = this.$el.ownerDocument;

      if (!doc) {
        return undefined;
      }

      if (this.hostId) {
        return doc.getElementById(this.hostId);
      } else {
        var defaultHostSelector = getDefaultTarget();
        return defaultHostSelector ? doc.querySelector(defaultHostSelector) : doc.body;
      }
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      if (!this.hasTarget) return;
      var classNames = this.classNames,
          hostId = this.hostId,
          append = this.append;
      return h(MountingPortal, {
        "attrs": {
          "mount-to": hostId ? "#".concat(hostId) : 'body',
          "append": append
        }
      }, [h("div", {
        "class": classNames.root
      }, [h("div", {
        "class": classNames.content
      }, [this.$slots.default])])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var className = this.className,
          theme = this.theme;
      return getClassNames(getStyles, {
        theme: theme,
        className: className,
        isNotHost: !this.hostId
      });
    }
  }]);

  return LayerBase;
}(BaseComponent);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], LayerBase.prototype, "hostId", void 0);

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], LayerBase.prototype, "append", void 0);

LayerBase = __decorate([Component], LayerBase);

export { LayerBase };
